import opendreams.proxy.OpenDreamsProxy;
import opendreams.proxy.Project;
import tecgraf.openbus.DRMAA.JobInfo;
import tecgraf.openbus.DRMAA.Session;
import tecgraf.openbus.opendreams.IOpenDreams;
import tecgraf.openbus.opendreams.OpenDreamsJobTemplate;

/**
 * Demo de execuo de um algoritmo que recebe um parmetro de arquivo como 
 * entrada e um parmetro de arquivo de sada.
 * @author Tecgraf PUC-Rio
 *
 */
public class ProjectDemoOpenDreams {

  /**
   * Executa o teste.
   * 
   * @param args argumentos da linha de comando. No possui argumentos de
   *        entrada.
   */
  public static void main(String[] args) {
    try {
      new ProjectDemoOpenDreams().run();
    }
    catch (Throwable e) {
      e.printStackTrace();
    }
    System.exit(0);
  }

  private void run() throws Exception {
    OpenDreamsProxy opendreamsProxy = new OpenDreamsProxy();
    opendreamsProxy.init();
    System.out.println("** Recuperando o componente OpenDreams...");
    Project project = opendreamsProxy.getProject();
    if (project==null) {
      System.out.println("Projeto no encontrado");
      return;
    }
    /*
     * Criando um arquivo de entrada no projeto.
     * Se o arquivo j existir, ele  removido antes de ser criado um novo.
     */
    String inputFileName = "Entrada.txt";
    if (project.hasFile(inputFileName)) {
      System.out.println("** Removendo o arquivo " + inputFileName + " que j existe");
      project.removeFile(inputFileName);
    }
    String content = "Teste de escrita em arquivo\n";
    System.out.println("** Criando um arquivo no projeto...");
    project.createFile(inputFileName, content.getBytes());

    /*
     * Removendo um arquivo de sada no projeto, no caso dele j existir.
     */
    String outputFileName = "Saida.txt";
    if (project.hasFile(outputFileName)) {
      System.out.println("** Removendo o arquivo " + outputFileName + " que j existe");
      project.removeFile(outputFileName);
    }
    
    /*
     * Executando o algoritmo "Teste_da_Demo_de_Projeto" que copia n vezes
     * o contedo de um arquivo de entrada para outro de sada.
     */
    IOpenDreams opendreams = opendreamsProxy.getIOpenDreams();
    Session session = opendreams.getSession(opendreamsProxy.getProperties().getProjectName());
    session.init("");
    OpenDreamsJobTemplate jt =
      (OpenDreamsJobTemplate) session.createJobTemplate();
    jt.setRemoteCommand("execAlgo");
    jt.setArgs(new String[] { "-name", "Teste_da_Demo_de_Projeto", "-version", "1.0.0" });
    jt.setJobDescription("Teste do Acesso ao Projeto");
    jt.addJobParameter("qtde", "6");
    jt.addJobParameter("arq_entrada", "Entrada.txt:TEXT");
    jt.addJobParameter("arq_saida", "Saida.txt:TEXT");
    jt.setOutputPath("stdout");
    //jt.setEmail(new String[]{"mjulia@tecgraf.puc-rio.br"});
    System.out.println("** Solicitando a execucao de " + jt.getRemoteCommand());
    System.out.print("** Argumentos: ");
    for (String arg : jt.getArgs()) {
      System.out.print(arg);
      System.out.print(" ");
    }
    System.out.println();
    System.out.println("** Parametro arq_entrada: " + jt.getJobParameter("arq_entrada"));
    System.out.println("** Parametro arq_saida: " + jt.getJobParameter("arq_saida"));
    System.out.println("** Parametro qtde: " + jt.getJobParameter("qtde"));
    System.out.println("** OutputPath: " + jt.getOutputPath());
    String jobName = session.runJob(jt);
    System.out.println("** Id do comando: " + jobName);
    session.deleteJobTemplate(jt);

    JobInfo jobInfo = session._wait(jobName, Session.TIMEOUT_WAIT_FOREVER);
    System.out.println("** Resultado: hasExited = " + jobInfo.hasExited
      + ": exitStatus = " + jobInfo.exitStatus);
    
    byte[] buffer = project.getDataFrom("stdout");
    System.out.println("** O log de sada do comando :");
    System.out.println(new String(buffer));
    session.exit();

    opendreamsProxy.close();
  }

}
